==> fluxbox-1.3.2.tar.xz: fluxbox-1.3.2/nls/it_IT/generated-UTF-8.m <==
$ codeset=UTF-8

$set 1 #Align

1 In basso al centro
2 In basso a sinistra
3 In basso a destra
6 A sinistra in basso
7 A sinistra al centro
8 A sinistra in alto
11 A destra in basso
12 A destra al centro
13 A destra in alto
14 In alto al centro
15 In alto a sinistra
16 In alto a destra

$set 2 #BaseDisplay
1 Interruzione... core dump\n
2 Arresto\n
3 %s:      ricevuto segnale %d\n

$set 3 #Common
1 Canale alfa
2 Nascondi automaticamente
3 Compilato
4 Opzioni compilate
5 Compilatore
6 Versione del compilatore
7     init
8     keys
9      nls
10     menu
11    style
12 Predefiniti
13 disabilitata
14 Errore
15 Versione di Fluxbox
16 Ingrandisci sopra tutto
17 Revisione GIT
18 Visibile
19 In questo tema non Ã¨ specificata un'opzione background.\nConsultare il manuale o leggere le FAQ.

$set 4 #Configmenu

2 In primo piano automaticamente
3 In primo piano al click
4 Clicca per avere il focus
8 Tipo di focus
9 Dai il focus alle nuove finestre
10 Massimo ingrandimento
12 Mostra il contenuto spostando le finestre
13 Focus al passaggio del mouse (modalitÃ  Strict)
14 Focus al passaggio del mouse
15 Cambia area di lavoro trascinando le finestre
16 Forza pseudo trasparenza
17 Canale alfa del menÃ¹
18 Trasparenza
19 Canale alfa della finestra focalizzata
20 Canale alfa della finestra non focalizzata
21 Opzioni tab
22 Tab nella barra del titolo
23 Larghezza del tab esterno
24 Clicca sul tab per avere il focus
25 Focus al passaggio del mouse sul tab
26 Opzioni ingrandimento
27 Ignora incremento di ridimensionamento
28 Disabilita movimento
29 Disabilita ridimensionamento

$set 6 #FbTkError

1 Attenzione! Altezza maggiore di 3200, sto impostando l'altezza a 3200
2 Attenzione! Larghezza maggiore di 3200, sto impostando la larghezza a 3200
3 Attenzione: impossibile caricare il carattere di riserva
4 Errore di allocazione.
5 Errore durante la creazione pixmap
6 Impossibile creare XImage
7 Impossibile leggere
8 Attenzione: impossibile trovare un formato valido per il canale alfa.
9 Attenzione: impossibile creare l'immagine con canale alfa.
10 Attenzione: impossibile creare la pixmap con canale alfa.
11 Impossibile trovare un formato per lo schermo(%d)
12 Memoria esaurita
13 Memoria esaurita durante l'allocazione del buffer blu.
14 Memoria esaurita durante l'allocazione del buffer verde.
15 Memoria esaurita durante l'allocazione del buffer rosso.
16 Impossibile leggere l'elemento del tema
17 visuale non supportata
18 Impostazione valore predefinito

$set 7 #Fluxbox

1 Il nome del rc non Ã¨ valido!
3 Impossibile caricare il database
4 Nuovo tentativo con
5 Attenzione! Impossibile trovare lo schermo su cui disegnare una finestra!
6 Impossibile creare la directory %s
7 Impossibile trovare schermi da gestire.\nAssicurarsi di non avere un altro window manager in esecuzione.
8 Errore nell'analisi dell'espressione regolare
9 Errore fatale! PuÃ² esserci solo un'istanza di una classe fluxbox.
10 Impossibile connettersi al server X.\nAssicurarsi di aver avviato X prima di Fluxbox.
11 Attenzione: il server X non gestisce la localizzazione
12 Attenzione: impossibile impostare i modificatori di localizzazione

$set 9 #Keys

1 Keys: errore alla linea
3 Keys: chiave o modificatore non valido alla linea

$set 10 #Menu

1 Configurazione
2 MenÃ¹ di Fluxbox predefinito
3 Uscita
4 Icone
5 Livello...
6 Sul monitor...
7 Posizionamento
8 Ricarica configurazione
9 Riavvio
10 Attenzione: tag [encoding] non bilanciati

$set 11 #Remember

1 Decorazioni
2 Dimensioni
3 Passa ad area di lavoro
4 Livello
5 Ricorda...
6 Posizione
7 Salva alla chiusura
8 Ridotta a barra
9 Su tutte le aree di lavoro
11 Area di lavoro
12 Monitor
13 Trasparenza
14 Ridotta
15 Ingrandita
16 A pieno schermo

$set 12 #Screen

1 BScreen::BScreen: si Ã¨ verificato un errore interrogando il server X.\n	sul display Ã¨ giÃ  in esecuzione un altro window manager
2 W: %4d x H: %4d
3 BScreen::BScreen: gestione dello schermo %d usando visuale 0x%lx, profonditÃ  %d\n
4 W: %04d x H: %04d

$set 13 #Slit

1 Client
2 Sposta in basso
3 Sposta in alto
4 Direzione dello slit:
5 Livello dello slit
6 Slit sul monitor
7 Posizionamento dello slit
8 Slit
9 Salva la lista dello slit

$set 14 #Toolbar

1 Cambia nome a quest'area di lavoro
2 ModalitÃ  delle icone della barra
3 Tutte le finestre
4 Icone
5 Nessuna
6 Area di lavoro
7 Icone dell'area di lavoro
8 Livello della barra degli strumenti
9 Barra degli strumenti sul monitor
10 Posizionamento della barra degli strumenti
11 Barra degli strumenti
12 Percentuale della larghezza della barra degli strumenti
13 Orologio: 24h
14 Orologio: 12h
15 Modifica il formato dell'orologio
16 Mostra le immagini
17 Nessuna icona
18 Nessuna icona per l'area di lavoro

$set 15 #Window

1 Senza nome

$set 16 #Windowmenu

1 Chiudi
2 Riduci a icona
3 Livello
4 Sullo sfondo
5 Ingrandisci
6 In primo piano
7 Invia a ...
8 Riduci a barra
9 Su tutte le aree di lavoro
12 Imposta il titolo della finestra

$set 17 #Workspace

1 Area di lavoro %d
2 Aree di lavoro
3 Crea una nuova
4 Elimina l'ultima

$set 18 #fbsetroot

1 errore: specificare una delle opzioni : -solid, -mod, -gradient\n
2 Impossibile creare atomi pixmap, abbandono!
3 -display <stringa>        connessione al display\n\
-mod <x> <y>              schema\n\
-foreground, -fg <colore> colore di primo piano nello schema\n\
-background, -bg <colore> colore di sfondo nello schema\n\n\
-gradient <texture>       tipo di gradazione\n\
-from <colore>            colore di partenza della gradazione\n\
-to <colore>              colore finale della gradazione\n\n\
-solid <colore>           colore pieno\n\n\
-help                     mostra questo messaggio ed esce\n

$set 19 #main

1 errore: '-display' richiede un argomento
2 Bad Alloc
3 Bad cast
4 Fuori campo
5 Errore di runtime
6 Eccezione standard
7 Errore sconosciuto
8 errore: '-log' richiede un argomento
9 File di log
10 Registrazione su
11 errore: '-rc' richiede un argomento
12 errore: '-screen' richiede un argomento
13 Fluxbox %s: (c) %s Henrik Kinnunen\n\n\

Sito web: http://www.fluxbox.org/\n\n\
-display <stringa>\t\tusa la connessione al display.\n\
-screen <all|int,int,int>\tesegue solo sugli schermi specificati.\n\
-rc <stringa>\t\t\tusa un file di configurazione alternativo.\n\
-version\t\t\tmostra la versione ed esce.\n\
-info\t\t\t\tmostra alcune informazioni utili.\n\
-list-commands\t\t\telenca tutti i comandi validi.\n\
-sync\t\t\t\tsincronizza con il server X per scopi di debug.\n\
-log <filename>\t\t\tregistra l'output su file.\n\
-help\t\t\t\tmostra questo messaggio di aiuto ed esce.\n\n
14 attenzione: impossibile impostare la variabile d'ambiente 'DISPLAY'

$set 20 #layers

1 Sopra il dock
2 Sotto tutto
3 Desktop
4 Dock
5 Normale
6 Sopra tutto

==> fluxbox-1.3.6.tar.xz: fluxbox-1.3.6/nls/it_IT/generated-UTF-8.m <==
$ codeset=UTF-8

$set 1 #Align

1 In basso al centro
2 In basso a sinistra
3 In basso a destra
6 A sinistra in basso
7 A sinistra al centro
8 A sinistra in alto
11 A destra in basso
12 A destra al centro
13 A destra in alto
14 In alto al centro
15 In alto a sinistra
16 In alto a destra

$set 2 #BaseDisplay
1 Interruzione... core dump\n
2 Arresto\n
3 %s:      ricevuto segnale %d\n

$set 3 #Common
1 Canale alfa
2 Nascondi automaticamente
3 Compilato
4 Opzioni compilate
5 Compilatore
6 Versione del compilatore
7     init
8     keys
9      nls
10     menu
11    style
12 Predefiniti
13 disabilitata
14 Errore
15 Versione di Fluxbox
16 Ingrandisci sopra tutto
17 Revisione GIT
18 Visibile
19 In questo tema non è specificata un'opzione background.\nConsultare il manuale o leggere le FAQ.

$set 4 #Configmenu

2 In primo piano automaticamente
3 In primo piano al click
4 Clicca per avere il focus
8 Tipo di focus
9 Dai il focus alle nuove finestre
10 Massimo ingrandimento
12 Mostra il contenuto spostando le finestre
13 Focus al passaggio del mouse (modalità Strict)
14 Focus al passaggio del mouse
15 Cambia area di lavoro trascinando le finestre
16 Forza pseudo trasparenza
17 Canale alfa del menù
18 Trasparenza
19 Canale alfa della finestra focalizzata
20 Canale alfa della finestra non focalizzata
21 Opzioni tab
22 Tab nella barra del titolo
23 Larghezza del tab esterno
24 Clicca sul tab per avere il focus
25 Focus al passaggio del mouse sul tab
26 Opzioni ingrandimento
27 Ignora incremento di ridimensionamento
28 Disabilita movimento
29 Disabilita ridimensionamento

$set 6 #FbTkError

1 Attenzione! Altezza maggiore di 3200, sto impostando l'altezza a 3200
2 Attenzione! Larghezza maggiore di 3200, sto impostando la larghezza a 3200
3 Attenzione: impossibile caricare il carattere di riserva
4 Errore di allocazione.
5 Errore durante la creazione pixmap
6 Impossibile creare XImage
7 Impossibile leggere
8 Attenzione: impossibile trovare un formato valido per il canale alfa.
9 Attenzione: impossibile creare l'immagine con canale alfa.
10 Attenzione: impossibile creare la pixmap con canale alfa.
11 Impossibile trovare un formato per lo schermo(%d)
12 Memoria esaurita
13 Memoria esaurita durante l'allocazione del buffer blu.
14 Memoria esaurita durante l'allocazione del buffer verde.
15 Memoria esaurita durante l'allocazione del buffer rosso.
16 Impossibile leggere l'elemento del tema
17 visuale non supportata
18 Impostazione valore predefinito

$set 7 #Fluxbox

1 Il nome del rc non è valido!
3 Impossibile caricare il database
4 Nuovo tentativo con
5 Attenzione! Impossibile trovare lo schermo su cui disegnare una finestra!
6 Impossibile creare la directory %s
7 Impossibile trovare schermi da gestire.\nAssicurarsi di non avere un altro window manager in esecuzione.
8 Errore nell'analisi dell'espressione regolare
9 Errore fatale! Può esserci solo un'istanza di una classe fluxbox.
10 Impossibile connettersi al server X.\nAssicurarsi di aver avviato X prima di Fluxbox.
11 Attenzione: il server X non gestisce la localizzazione
12 Attenzione: impossibile impostare i modificatori di localizzazione

$set 9 #Keys

1 Keys: errore alla linea
3 Keys: chiave o modificatore non valido alla linea

$set 10 #Menu

1 Configurazione
2 Menù di Fluxbox predefinito
3 Uscita
4 Icone
5 Livello...
6 Sul monitor...
7 Posizionamento
8 Ricarica configurazione
9 Riavvio
10 Attenzione: tag [encoding] non bilanciati

$set 11 #Remember

1 Decorazioni
2 Dimensioni
3 Passa ad area di lavoro
4 Livello
5 Ricorda...
6 Posizione
7 Salva alla chiusura
8 Ridotta a barra
9 Su tutte le aree di lavoro
11 Area di lavoro
12 Monitor
13 Trasparenza
14 Ridotta
15 Ingrandita
16 A pieno schermo

$set 12 #Screen

1 BScreen::BScreen: si è verificato un errore interrogando il server X.\n	sul display è già in esecuzione un altro window manager
2 W: %4d x H: %4d
3 BScreen::BScreen: gestione dello schermo %d usando visuale 0x%lx, profondità %d\n
4 W: %04d x H: %04d

$set 13 #Slit

1 Client
2 Sposta in basso
3 Sposta in alto
4 Direzione dello slit:
5 Livello dello slit
6 Slit sul monitor
7 Posizionamento dello slit
8 Slit
9 Salva la lista dello slit

$set 14 #Toolbar

1 Cambia nome a quest'area di lavoro
2 Modalità delle icone della barra
3 Tutte le finestre
4 Icone
5 Nessuna
6 Area di lavoro
7 Icone dell'area di lavoro
8 Livello della barra degli strumenti
9 Barra degli strumenti sul monitor
10 Posizionamento della barra degli strumenti
11 Barra degli strumenti
12 Percentuale della larghezza della barra degli strumenti
13 Orologio: 24h
14 Orologio: 12h
15 Modifica il formato dell'orologio
16 Mostra le immagini
17 Nessuna icona
18 Nessuna icona per l'area di lavoro

$set 15 #Window

1 Senza nome

$set 16 #Windowmenu

1 Chiudi
2 Riduci a icona
3 Livello
4 Sullo sfondo
5 Ingrandisci
6 In primo piano
7 Invia a ...
8 Riduci a barra
9 Su tutte le aree di lavoro
12 Imposta il titolo della finestra

$set 17 #Workspace

1 Area di lavoro %d
2 Aree di lavoro
3 Crea una nuova
4 Elimina l'ultima

$set 18 #fbsetroot

1 errore: specificare una delle opzioni : -solid, -mod, -gradient\n
2 Impossibile creare atomi pixmap, abbandono!
3 -display <stringa>        connessione al display\n\
-mod <x> <y>              schema\n\
-foreground, -fg <colore> colore di primo piano nello schema\n\
-background, -bg <colore> colore di sfondo nello schema\n\n\
-gradient <texture>       tipo di gradazione\n\
-from <colore>            colore di partenza della gradazione\n\
-to <colore>              colore finale della gradazione\n\n\
-solid <colore>           colore pieno\n\n\
-help                     mostra questo messaggio ed esce\n

$set 19 #main

1 errore: '-display' richiede un argomento
2 Bad Alloc
3 Bad cast
4 Fuori campo
5 Errore di runtime
6 Eccezione standard
7 Errore sconosciuto
8 errore: '-log' richiede un argomento
9 File di log
10 Registrazione su
11 errore: '-rc' richiede un argomento
12 errore: '-screen' richiede un argomento
13 Fluxbox %s: (c) %s Henrik Kinnunen\n\n\
Sito web: http://www.fluxbox.org/\n\n\
-display <stringa>\t\tusa la connessione al display.\n\
-screen <all|int,int,int>\tesegue solo sugli schermi specificati.\n\
-rc <stringa>\t\t\tusa un file di configurazione alternativo.\n\
-version\t\t\tmostra la versione ed esce.\n\
-info\t\t\t\tmostra alcune informazioni utili.\n\
-list-commands\t\t\telenca tutti i comandi validi.\n\
-sync\t\t\t\tsincronizza con il server X per scopi di debug.\n\
-log <filename>\t\t\tregistra l'output su file.\n\
-help\t\t\t\tmostra questo messaggio di aiuto ed esce.\n\n
14 attenzione: impossibile impostare la variabile d'ambiente 'DISPLAY'

$set 20 #layers

1 Sopra il dock
2 Sotto tutto
3 Desktop
4 Dock
5 Normale
6 Sopra tutto
